@@ -1,5 +1,6 @@
 /* Keep track of visited URLs in spider mode.
-   Copyright (C) 2006-2011, 2015, 2019 Free Software Foundation, Inc.
+   Copyright (C) 2006-2011, 2015, 2019-2022 Free Software Foundation,
+   Inc.
 
 This file is part of GNU Wget.
 
@@ -44,12 +45,14 @@ static struct hash_table *nonexisting_urls_set;
 
 /* Cleanup the data structures associated with this file.  */
 
+#if defined DEBUG_MALLOC || defined TESTING
 void
 spider_cleanup (void)
 {
   if (nonexisting_urls_set)
     string_set_free (nonexisting_urls_set);
 }
+#endif
 
 /* Remembers broken links.  */
 void
